aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/skyframe/AggregatingArtifactValue.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/skyframe/AggregatingArtifactValue.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/skyframe/AggregatingArtifactValue.java24
1 files changed, 18 insertions, 6 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/skyframe/AggregatingArtifactValue.java b/src/main/java/com/google/devtools/build/lib/skyframe/AggregatingArtifactValue.java
index e6e045bce4..c8a56a2772 100644
--- a/src/main/java/com/google/devtools/build/lib/skyframe/AggregatingArtifactValue.java
+++ b/src/main/java/com/google/devtools/build/lib/skyframe/AggregatingArtifactValue.java
@@ -23,17 +23,29 @@ import java.util.Collection;
/** Value for aggregating artifacts, which must be expanded to a set of other artifacts. */
class AggregatingArtifactValue implements SkyValue {
private final FileArtifactValue selfData;
- private final ImmutableList<Pair<Artifact, FileArtifactValue>> inputs;
+ private final ImmutableList<Pair<Artifact, FileArtifactValue>> fileInputs;
+ private final ImmutableList<Pair<Artifact, TreeArtifactValue>> directoryInputs;
- AggregatingArtifactValue(ImmutableList<Pair<Artifact, FileArtifactValue>> inputs,
+ AggregatingArtifactValue(
+ ImmutableList<Pair<Artifact, FileArtifactValue>> fileInputs,
+ ImmutableList<Pair<Artifact, TreeArtifactValue>> directoryInputs,
FileArtifactValue selfData) {
- this.inputs = inputs;
+ this.fileInputs = fileInputs;
+ this.directoryInputs = directoryInputs;
this.selfData = selfData;
}
- /** Returns the artifacts that this artifact expands to, together with their data. */
- Collection<Pair<Artifact, FileArtifactValue>> getInputs() {
- return inputs;
+ /** Returns the none tree artifacts that this artifact expands to, together with their data. */
+ Collection<Pair<Artifact, FileArtifactValue>> getFileArtifacts() {
+ return fileInputs;
+ }
+
+ /**
+ * Returns the tree artifacts that this artifact expands to, together with the information
+ * to which artifacts the tree artifacts expand to.
+ */
+ Collection<Pair<Artifact, TreeArtifactValue>> getTreeArtifacts() {
+ return directoryInputs;
}
/** Returns the data of the artifact for this value, as computed by the action cache checker. */